aboutsummaryrefslogtreecommitdiff
path: root/test/UtilsTests.cpp
diff options
context:
space:
mode:
authortelsoa01 <telmo.soares@arm.com>2018-08-31 09:31:35 +0100
committertelsoa01 <telmo.soares@arm.com>2018-08-31 09:31:35 +0100
commitce3e84a8d449cbf31cee57e30f0eef6a96c0ce94 (patch)
tree77a769e27879fb712027c990071b061c5e0e3b60 /test/UtilsTests.cpp
parentdeb3bdbe028a59da0759dd7a560387d03a11d322 (diff)
downloadandroid-nn-driver-ce3e84a8d449cbf31cee57e30f0eef6a96c0ce94.tar.gz
Release 18.08
Diffstat (limited to 'test/UtilsTests.cpp')
-rw-r--r--test/UtilsTests.cpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/test/UtilsTests.cpp b/test/UtilsTests.cpp
index e7e6cde7..72b6d361 100644
--- a/test/UtilsTests.cpp
+++ b/test/UtilsTests.cpp
@@ -16,9 +16,10 @@
BOOST_AUTO_TEST_SUITE(UtilsTests)
-using namespace armnn_driver;
-using namespace android::nn;
using namespace android;
+using namespace android::nn;
+using namespace android::hardware;
+using namespace armnn_driver;
// The following are helpers for writing unit tests for the driver.
namespace
@@ -28,9 +29,9 @@ struct ExportNetworkGraphFixture
{
public:
// Setup: set the output dump directory and an empty dummy model (as only its memory address is used).
// Defaulting the output dump directory to "/sdcard" because it should exist and be writable in all deployments.
ExportNetworkGraphFixture()
- : ExportNetworkGraphFixture("/sdcard")
+ : ExportNetworkGraphFixture("/data")
{}
ExportNetworkGraphFixture(const std::string& requestInputsAndOutputsDumpDir)
: m_RequestInputsAndOutputsDumpDir(requestInputsAndOutputsDumpDir)
@@ -95,7 +96,7 @@ public:
}
std::string m_RequestInputsAndOutputsDumpDir;
- V1_0::Model m_Model;
+ neuralnetworks::V1_0::Model m_Model;
private:
std::string m_FileName;
@@ -28,9 +29,9 @@ struct ExportNetworkGraphFixture
public:
// Setup: set the output dump directory and an empty dummy model (as only its memory address is used).
- // Defaulting the output dump directory to "/sdcard" because it should exist and be writable in all deployments.
+ // Defaulting the output dump directory to "/data" because it should exist and be writable in all deployments.
ExportNetworkGraphFixture()